@@ -1,5 +1,5 @@
 package Elastic::Model::Types;
-$Elastic::Model::Types::VERSION = '0.50';
+$Elastic::Model::Types::VERSION = '0.51';
 use strict;
 use warnings;
 use Search::Elasticsearch();
@@ -50,10 +50,7 @@ my @enums = (
         'date',   'ip',      'geo_point'
     ],
     TermVectorMapping,
-    [   'no',           'yes',
-        'with_offsets', 'with_positions',
-        'with_positions_offsets'
-    ],
+    [ 'no', 'yes', 'with_offsets', 'with_positions', 'with_positions_offsets' ],
     IndexMapping,
     [ 'analyzed', 'not_analyzed', 'no' ],
     DynamicMapping,
@@ -76,7 +73,7 @@ while ( my $type = shift @enums ) {
     );
 }
 
-class_type ES_1x, { class => 'Search::Elasticsearch::Client::Direct' };
+class_type ES_1x, { class => 'Search::Elasticsearch::Client::1_0::Direct' };
 class_type ES_90, { class => 'Search::Elasticsearch::Client::0_90::Direct' };
 
 #===================================
@@ -208,7 +205,7 @@ Elastic::Model::Types - MooseX::Types for general and internal use
 
 =head1 VERSION
 
-version 0.50
+version 0.51
 
 =head1 SYNOPSIS
 
@@ -296,7 +293,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2015 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
